@@ -10,8 +10,6 @@
 #  License for the specific language governing permissions and limitations
 #  under the License.
 
-import logging
-
 from django import shortcuts
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import ungettext_lazy
@@ -22,9 +20,6 @@ from django.core.urlresolvers import reverse
 import disaster_recovery.api.api as freezer_api
 
 
-LOG = logging.getLogger(__name__)
-
-
 class DeleteAction(tables.DeleteAction):
     name = "delete"
     classes = ("btn-danger",)
@@ -102,6 +97,9 @@ class ActionsTable(tables.DataTable):
     storage = tables.Column('storage', verbose_name=_("Storage"))
     mode = tables.Column('mode', verbose_name=_("Mode"))
 
+    def get_object_display(self, action):
+        return action.backup_name
+
     class Meta:
         name = "actions_table"
         verbose_name = _("Actions")
